@@ -8,6 +8,7 @@ from cnvrg.helpers.url_builder_helper import url_join
 import urllib
 import ssl
 from cnvrg.helpers.error_catcher import suppress_exception
+import urllib3
 
 JSON_HEADERS = {
     "Content-Type": "application/json"
@@ -32,6 +33,7 @@ def __parse_resp(resp, **kwargs):
 
 @suppress_exception
 def request(action, url, **kwargs):
+    urllib3.disable_warnings()
     callee = getattr(session, action)
     try:
         resp = callee(url, **kwargs)
@@ -41,35 +43,38 @@ def request(action, url, **kwargs):
 
 @suppress_exception
 def get_v2(url):
+    urllib3.disable_warnings()
     verify_logged_in()
     get_url = url_join(credentials.api_url, "v2", url)
-    return requests.get(url=get_url, headers={"Auth-Token": credentials.token})
+    return requests.get(url=get_url, headers={"Auth-Token": credentials.token}, verify=False)
 
 @suppress_exception
 def get(url, data=None):
     verify_logged_in()
     get_url = url_join(base_url, url)
-    return request('get', get_url, timeout=420, params=data)
+    return request('get', get_url, timeout=420, params=data, verify=False)
 
 
 @suppress_exception
 def post(url, data=None, files=None):
     verify_logged_in()
     get_url = url_join(base_url, url)
-    return request('post', get_url, timeout=900, data=json.dumps(data), files=files)
+    return request('post', get_url, timeout=900, data=json.dumps(data), files=files, verify=False)
 
 @suppress_exception
 def post_v2(url, data):
+    urllib3.disable_warnings()
     verify_logged_in()
     get_url = url_join(credentials.api_url, "v2", url)
-    return requests.post(url=get_url, json=data, headers={"Auth-Token": credentials.token})
+    return requests.post(url=get_url, json=data, headers={"Auth-Token": credentials.token}, verify=False)
 
 
 @suppress_exception
 def send_file(url, data=None, files=None):
+    urllib3.disable_warnings()
     verify_logged_in()
     get_url = url_join(base_url, url)
-    resp = requests.post(get_url, files=files, data=data, headers={"AUTH-TOKEN": credentials.token})
+    resp = requests.post(get_url, files=files, data=data, headers={"AUTH-TOKEN": credentials.token}, verify=False)
     return __parse_resp(resp, url=url, data=data)
 
 
@@ -77,10 +82,8 @@ def send_file(url, data=None, files=None):
 def put(url, data=None):
     verify_logged_in()
     get_url = url_join(base_url, url)
-    return request('put', get_url, timeout=900, data=json.dumps(data))
+    return request('put', get_url, timeout=900, data=json.dumps(data), verify=False)
 
-
-# @suppress_exception
 def download_file(url, fpath):
     try:
         ssl._create_default_https_context = ssl._create_unverified_context
@@ -89,16 +92,23 @@ def download_file(url, fpath):
     except Exception as e:
         print(e)
 
-
 @suppress_exception
 def download_raw_file(url):
-    resp = requests.get(url)
+    resp = requests.get(url, verify=False)
     return resp.content
 
 @suppress_exception
-def update_credentials():
+def update_credentials(creds):
     global credentials
-    credentials = auth_helper.CnvrgCredentials()
+    credentials = creds
+    global session
+    session = requests.session()
+    session.headers = {
+        "AUTH-TOKEN": credentials.token,
+        **JSON_HEADERS
+    }
+    global base_url
+    base_url = url_join(credentials.api_url, "v1")
 
 
 credentials = auth_helper.CnvrgCredentials()
