@@ -20,6 +20,8 @@ import traceback
 import pandas as pd
 import csv
 
+from cnvrg.modules.endpoint_version_data import EndpointVersionData
+
 
 class Endpoint(CnvrgJob):
     def __init__(self, endpoint=None, project=None):
@@ -56,11 +58,21 @@ class Endpoint(CnvrgJob):
     def log_request(self, input_params="", result="", start_time=None):
         hash = {}
         if self.log_input:
-            hash["input"] = str(input_params)[:1000]
+            input_str = str(input_params)
+            if len(input_str) > 1000:
+                print("Input was cropped due to log size (limited to 1000 chars)")
+                print("full input: {}".format(input_str))
+                input_str = input_str[:1000]
+            hash["input"] = input_str
         else:
             hash["input"] = ""
         if self.log_output:
-            hash["output"] = str(result)[:1000]
+            output_str = str(result)
+            if len(output_str) > 1000:
+                print("Output was cropped due to log size (limited to 1000 chars)")
+                print("full output: {}".format(output_str))
+                output_str = output_str[:1000]
+            hash["output"] = output_str
         else:
             hash["output"] = ""
         hash["start_time"] = str(datetime.datetime.utcfromtimestamp(int(start_time)))
@@ -213,6 +225,38 @@ class Endpoint(CnvrgJob):
         self._refresh_data()
         return self.__data
 
+    @property
+    def title(self):
+        return self.data.get("title")
+
+    @property
+    def url(self):
+        return self.data.get("endpoint_url")
+
+    @property
+    def model_url(self):
+        return self.data.get("public_url")
+
+    @property
+    def model_grpc_url(self):
+        return self.data.get("grpc_url")
+
+    @property
+    def min_replica(self):
+        return self.data.get("min_replica")
+
+    @property
+    def max_replica(self):
+        return self.data.get("max_replica")
+    
+    @property
+    def active_versions(self):
+        return len(self.data.get("deployments"))
+
+    @property
+    def status(self):
+        return self.data.get("status")
+
     @suppress_exception
     def __get_endpoint(self):
         return apis_helper.get(self.__base_url()).get("endpoint")
@@ -233,6 +277,11 @@ class Endpoint(CnvrgJob):
         }
         return session
 
+    def version(self, version):
+        if 0 <= version < len(self.data.get("deployments")):
+            return EndpointVersionData(self.data.get("deployments")[version])
+        return EndpointVersionData(self.data.get("last_deployment"))
+
     def predict(self, o):
         endpoint_url = self.data.get("endpoint_url")
         if not endpoint_url:
