@@ -1,9 +1,9 @@
 import os
 
-from cnvrg.modules.storage.base_storage import BaseStorage
-from cnvrg.modules.cnvrg_files import CnvrgFiles
 from typing import Dict
-from azure.storage.blob import BlockBlobService
+from azure.storage.blob import BlobServiceClient
+from cnvrg.modules.cnvrg_files import CnvrgFiles
+from cnvrg.modules.storage.base_storage import BaseStorage
 
 
 class AzureStorage(BaseStorage):
@@ -23,14 +23,14 @@ class AzureStorage(BaseStorage):
         container = props["container"]
 
         self.access_key = "DefaultEndpointsProtocol=https;AccountName={};AccountKey={};EndpointSuffix=core.windows.net".format(account_name, accout_key)
-        self.accout_key = accout_key
         self.container_name = container
-        self.account_name = account_name
         self.service = self._get_service()
 
     def upload_single_file(self, file, target):
         try:
-            self.service.create_blob_from_path(self.container_name, target, file)
+            client = self.service.get_blob_client(self.container_name, blob=target)
+            with open(file, "rb") as data:
+                client.upload_blob(data, overwrite=True)
         except Exception as e:
             print(e)
 
@@ -38,4 +38,4 @@ class AzureStorage(BaseStorage):
         pass
 
     def _get_service(self):
-        return BlockBlobService(account_name=self.account_name, account_key=self.accout_key)
+        return BlobServiceClient.from_connection_string(self.access_key)
